package com.xynet.marketing.controller.inner;

import com.xynet.marketing.service.MercService;
import com.xynet.marketing.service.factory.coupon.merc.MercCouponFactory;
import com.xynet.marketing.utils.FactoryUtils;
import com.xynet.marketing.utils.R;
import com.xynet.marketing.utils.collections.map.JHashMap;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * 优惠券的发放
 *
 * @author hechunping
 * @date 2025/2/26
 */
@RestController
@RequestMapping("inner/coupon")
@AllArgsConstructor
@Slf4j
@CrossOrigin(origins = "*")
public class InnerCouponController {

    private MercService mercService;

    /**
     * 会员注册时-发送优惠券给会员
     *
     * @param param
     * @param headers
     * @return
     */
    @PostMapping("registerSend")
    public R registerSend(@RequestBody JHashMap<String, Object> param, @RequestHeader Map<String, String> headers) {
        MercCouponFactory mercCouponFactory = FactoryUtils.getService(MercCouponFactory.class, "merc_coupon_base");
        Integer mercId = mercService.thirdMercIdToMercId(headers.get("provider-id"), param.getString("thirdMercId"));
        param.put("mercId", mercId);
        return R.ok(mercCouponFactory.registerSend(param));
    }

    /**
     * 会员订单支付成功时-发送优惠券给会员
     *
     * @param param
     * @param headers
     * @return
     */
    @PostMapping("orderSend")
    public R orderSend(@RequestBody JHashMap<String, Object> param, @RequestHeader Map<String, String> headers) {
        MercCouponFactory mercCouponFactory = FactoryUtils.getService(MercCouponFactory.class, "merc_coupon_base");
        Integer mercId = mercService.thirdMercIdToMercId(headers.get("provider-id"), param.getString("thirdMercId"));
        param.put("mercId", mercId);
        return R.ok(mercCouponFactory.orderSend(param));
    }

    /**
     * 指定类型-发送优惠券给会员
     *
     * @param param
     * @param headers
     * @return
     */
    @PostMapping("sendByType")
    public R sendByType(@RequestBody JHashMap<String, Object> param, @RequestHeader Map<String, String> headers) {
        MercCouponFactory mercCouponFactory = FactoryUtils.getService(MercCouponFactory.class, "merc_coupon_base");
        Integer mercId = mercService.thirdMercIdToMercId(headers.get("provider-id"), param.getString("thirdMercId"));
        param.put("mercId", mercId);
        return R.ok(mercCouponFactory.commonSend(param));
    }

}
